==> sugarcrm-5.5.1.tbz: www/sugarcrm/include/SugarObjects/templates/person/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2010 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/
$mod_strings = array(
'LBL_SALUTATION'=>'Salutation',
'LBL_NAME'=>'Name',
'LBL_FIRST_NAME'=>'First Name',
'LBL_LAST_NAME'=>'Last Name', 
'LBL_TITLE'=>'Title',
'LBL_DEPARTMENT'=>'Department',
'LBL_DO_NOT_CALL'=>'Do Not Call',
'LBL_HOME_PHONE'=>'Home Phone',
'LBL_MOBILE_PHONE'=>'Mobile Phone',
'LBL_OFFICE_PHONE'=>'Work Phone',
'LBL_OTHER_PHONE'=>'Other Phone',
'LBL_FAX_PHONE'=>'Fax',
'LBL_EMAIL_ADDRESS'=>'Email Address(es)',
'LBL_PRIMARY_ADDRESS'=>'Primary Address', 
'LBL_PRIMARY_ADDRESS_STREET'=>'Primary Address',
'LBL_PRIMARY_ADDRESS_STREET_2' => 'Primary Address Street 2:',
'LBL_PRIMARY_ADDRESS_STREET_3' => 'Primary Address Street 3:',
'LBL_PRIMARY_ADDRESS_CITY'=>'Primary City',
'LBL_PRIMARY_ADDRESS_STATE'=>'Primary State',
'LBL_PRIMARY_ADDRESS_POSTALCODE'=>'Primary Postal Code',
'LBL_PRIMARY_ADDRESS_COUNTRY' => 'Primary Address Country:',
'LBL_ALT_ADDRESS_STREET'=>'Alternate Address',
'LBL_ALT_ADDRESS_STREET_2' => 'Alternate Address Street 2:',
'LBL_ALT_ADDRESS_STREET_3' => 'Alternate Address Street 3:',
'LBL_ALT_ADDRESS_CITY'=>'Alternate City',
'LBL_ALT_ADDRESS_STATE'=>'Alternate State',
'LBL_ALT_ADDRESS_POSTALCODE'=>'Alternate Postal Code',
'LBL_ALT_ADDRESS_COUNTRY'=>'Alternate Country',
'LBL_COUNTRY'=>'Country',
'LBL_STREET'=>'Other Address',
'LBL_CITY'=>'City',
'LBL_STATE'=>'State',
'LBL_POSTALCODE'=>'Postal Code',
'LBL_POSTAL_CODE'=>'Postal Code',
'LBL_COUNTRY'=>'Country',
'LBL_CONTACT_INFORMATION'=>'Contact Information',
'LBL_ADDRESS_INFORMATION'=>'Address(es)',
'LBL_CONTACT_INFORMATION'=>'Contact Information',
'LBL_OTHER_EMAIL_ADDRESS' => 'Other Email:',
'LBL_ASSIGNED_TO_NAME'=>'Assigned to',
'LBL_ASSISTANT'=>'Assistant',
'LBL_ASSISTANT_PHONE'=>'Assistant Phone',
'LBL_WORK_PHONE'=>'Work Phone',
'LNK_IMPORT_VCARD' => 'Create From vCard',
);

==> sugarcrm-6.2.1.tbz: www/sugarcrm/include/SugarObjects/templates/person/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/

$mod_strings = array(
'LBL_SALUTATION'=>'Salutation',
'LBL_NAME'=>'Name',
'LBL_FIRST_NAME'=>'First Name',
'LBL_LAST_NAME'=>'Last Name', 
'LBL_TITLE'=>'Title',
'LBL_DEPARTMENT'=>'Department',
'LBL_DO_NOT_CALL'=>'Do Not Call',
'LBL_HOME_PHONE'=>'Home Phone',
'LBL_MOBILE_PHONE'=>'Mobile Phone',
'LBL_OFFICE_PHONE'=>'Office Phone',
'LBL_OTHER_PHONE'=>'Other Phone',
'LBL_FAX_PHONE'=>'Fax',
'LBL_EMAIL_ADDRESS'=>'Email Address(es)',
'LBL_PRIMARY_ADDRESS'=>'Primary Address', 
'LBL_PRIMARY_ADDRESS_STREET'=>'Primary Address',
'LBL_PRIMARY_ADDRESS_STREET_2' => 'Primary Address Street 2:',
'LBL_PRIMARY_ADDRESS_STREET_3' => 'Primary Address Street 3:',
'LBL_PRIMARY_ADDRESS_CITY'=>'Primary City',
'LBL_PRIMARY_ADDRESS_STATE'=>'Primary State',
'LBL_PRIMARY_ADDRESS_POSTALCODE'=>'Primary Postal Code',
'LBL_PRIMARY_ADDRESS_COUNTRY' => 'Primary Address Country:',
'LBL_ALT_ADDRESS'=>'Alternate Address', 
'LBL_ALT_ADDRESS_STREET'=>'Alternate Address',
'LBL_ALT_ADDRESS_STREET_2' => 'Alternate Address Street 2:',
'LBL_ALT_ADDRESS_STREET_3' => 'Alternate Address Street 3:',
'LBL_ALT_ADDRESS_CITY'=>'Alternate City',
'LBL_ALT_ADDRESS_STATE'=>'Alternate State',
'LBL_ALT_ADDRESS_POSTALCODE'=>'Alternate Postal Code',
'LBL_ALT_ADDRESS_COUNTRY'=>'Alternate Country',
'LBL_COUNTRY'=>'Country',
'LBL_STREET'=>'Other Address',
'LBL_CITY'=>'City',
'LBL_STATE'=>'State',
'LBL_POSTALCODE'=>'Postal Code',
'LBL_POSTAL_CODE'=>'Postal Code',
'LBL_COUNTRY'=>'Country',
'LBL_CONTACT_INFORMATION'=>'Contact Information',
'LBL_ADDRESS_INFORMATION'=>'Address(es)',
'LBL_CONTACT_INFORMATION'=>'Contact Information',
'LBL_ASSIGNED_TO_NAME'=>'User',
'LBL_OTHER_EMAIL_ADDRESS' => 'Other Email:',
'LBL_ASSISTANT'=>'Assistant',
'LBL_ASSISTANT_PHONE'=>'Assistant Phone',
'LBL_WORK_PHONE'=>'Work Phone',
'LNK_IMPORT_VCARD' => 'Create From vCard',
);
